==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkScalarBarRepresentation.java <==
// java wrapper for vtkScalarBarRepresentation object
//

package vtk;
import vtk.*;

public class vtkScalarBarRepresentation extends vtkBorderRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetScalarBarActor_2();
  public vtkScalarBarActor GetScalarBarActor() {
    long temp = GetScalarBarActor_2();

    if (temp == 0) return null;
    return (vtkScalarBarActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalarBarActor_3(vtkScalarBarActor id0);
  public void SetScalarBarActor(vtkScalarBarActor id0)
    { SetScalarBarActor_3(id0); }

  private native void BuildRepresentation_4();
  public void BuildRepresentation()
    { BuildRepresentation_4(); }

  private native void WidgetInteraction_5(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_5(id0); }

  private native void GetSize_6(double id0[]);
  public void GetSize(double id0[])
    { GetSize_6(id0); }

  private native int GetVisibility_7();
  public int GetVisibility()
    { return GetVisibility_7(); }

  private native void SetVisibility_8(int id0);
  public void SetVisibility(int id0)
    { SetVisibility_8(id0); }

  private native void GetActors2D_9(vtkPropCollection id0);
  public void GetActors2D(vtkPropCollection id0)
    { GetActors2D_9(id0); }

  private native void ReleaseGraphicsResources_10(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_10(id0); }

  private native int RenderOverlay_11(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_11(id0); }

  private native int RenderOpaqueGeometry_12(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_12(id0); }

  private native int RenderTranslucentPolygonalGeometry_13(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_13(id0); }

  private native int HasTranslucentPolygonalGeometry_14();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_14(); }

  private native void SetAutoOrient_15(boolean id0);
  public void SetAutoOrient(boolean id0)
    { SetAutoOrient_15(id0); }

  private native boolean GetAutoOrient_16();
  public boolean GetAutoOrient()
    { return GetAutoOrient_16(); }

  private native void SetOrientation_17(int id0);
  public void SetOrientation(int id0)
    { SetOrientation_17(id0); }

  private native int GetOrientation_18();
  public int GetOrientation()
    { return GetOrientation_18(); }

  public vtkScalarBarRepresentation() { super(); }

  public vtkScalarBarRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-9-armv7h.pkg.tar.xz: vtk/vtkScalarBarRepresentation.java <==
// java wrapper for vtkScalarBarRepresentation object
//

package vtk;
import vtk.*;

public class vtkScalarBarRepresentation extends vtkBorderRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetScalarBarActor_2();
  public vtkScalarBarActor GetScalarBarActor() {
    long temp = GetScalarBarActor_2();

    if (temp == 0) return null;
    return (vtkScalarBarActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalarBarActor_3(vtkScalarBarActor id0);
  public void SetScalarBarActor(vtkScalarBarActor id0)
    { SetScalarBarActor_3(id0); }

  private native void BuildRepresentation_4();
  public void BuildRepresentation()
    { BuildRepresentation_4(); }

  private native void WidgetInteraction_5(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_5(id0); }

  private native void GetSize_6(double id0[]);
  public void GetSize(double id0[])
    { GetSize_6(id0); }

  private native int GetVisibility_7();
  public int GetVisibility()
    { return GetVisibility_7(); }

  private native void SetVisibility_8(int id0);
  public void SetVisibility(int id0)
    { SetVisibility_8(id0); }

  private native void GetActors2D_9(vtkPropCollection id0);
  public void GetActors2D(vtkPropCollection id0)
    { GetActors2D_9(id0); }

  private native void ReleaseGraphicsResources_10(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_10(id0); }

  private native int RenderOverlay_11(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_11(id0); }

  private native int RenderOpaqueGeometry_12(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_12(id0); }

  private native int RenderTranslucentPolygonalGeometry_13(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_13(id0); }

  private native int HasTranslucentPolygonalGeometry_14();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_14(); }

  private native void SetAutoOrient_15(boolean id0);
  public void SetAutoOrient(boolean id0)
    { SetAutoOrient_15(id0); }

  private native boolean GetAutoOrient_16();
  public boolean GetAutoOrient()
    { return GetAutoOrient_16(); }

  private native void SetOrientation_17(int id0);
  public void SetOrientation(int id0)
    { SetOrientation_17(id0); }

  private native int GetOrientation_18();
  public int GetOrientation()
    { return GetOrientation_18(); }

  public vtkScalarBarRepresentation() { super(); }

  public vtkScalarBarRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
